@@ -1,23 +1,20 @@
 use strict;
 package Event::Stats;
 use Carp;
-use Event 0.53;
+use Event 0.33;
 use base ('Exporter', 'DynaLoader');
 use vars qw($VERSION @EXPORT_OK);
-$VERSION = '0.10';
+$VERSION = '0.5';
 @EXPORT_OK = qw(round_seconds idle_time total_time);
 
 __PACKAGE__->bootstrap($VERSION);
 
 sub enforce_max_callback_time {
-    # a bit kludged
-    if (@_) {
-	my ($yes) = @_;
-	$SIG{ALRM} = sub { Carp::confess("Event timed out") } if $yes;
-	_enforce_max_callback_time($yes);
-    } else {
-	_enforcing_max_callback_time()
-    }
+    my ($yes) = @_;
+    $SIG{ALRM} = sub {
+	Carp::confess("Event timed out")
+    } if $yes;
+    _enforce_max_callback_time($yes);
 }
 
 1;
@@ -33,7 +30,7 @@ XXX
 
 =head1 DESCRIPTION
 
-Instrument the Event module in order to gather statistics.
+XXX
 
 =head1 API
 
@@ -79,7 +76,7 @@ mailing list!
 
 =head1 COPYRIGHT
 
-Copyright  1999, 2000 Joshua Nathaniel Pritikin.  All rights reserved.
+Copyright  1999 Joshua Nathaniel Pritikin.  All rights reserved.
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
